<?php

/*
 * LMS version 1.3-cvs
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: userbalanceok.php,v 1.18 2004/03/11 17:24:22 lukasz Exp $
 */

$layout['pagetitle'] = "Rozliczenie uytkownika ID: ".sprintf("%04d",$_GET['id']);
$SMARTY->assign('userid',$_GET['id']);

if (!$LMS->UserExists($_GET['id']))
{
	$body = "<H1>".$layout['pagetitle']."</H1><P>Podany przez Ciebie ID jest bdny bd nie istnieje w bazie danych.</P>";
}
else
{
	$LMS->SetBalanceZero($_GET['id']);
	header("Location: ?m=".$_SESSION['lastmodule']);
}

$SMARTY->display('header.html');
$SMARTY->assign('body',$body);
$SMARTY->display('dialog.html');
$SMARTY->display('footer.html');

?>